@@ -76,11 +76,12 @@ class ModelSeeder(object):
 
         return formatters
 
-    def execute(self, using, inserted_entities):
+    def execute(self, using, inserted_entities, skip_if_exists=False):
         """
         Execute the stages entities to insert
         :param using:
         :param inserted_entities:
+        :param skip_if_exists: if True, will not insert if the entity already exists
         """
 
         def format_field(format, inserted_entities):
@@ -104,10 +105,15 @@ class ModelSeeder(object):
                     for field, field_format in self.field_formatters.items()
                 })
                 return obj.pk
-            except (django.db.utils.IntegrityError, django.db.utils.DataError) as e:
+            except django.db.utils.DataError as e:
                 print(e)
                 continue
 
+            except django.db.utils.IntegrityError as e:
+                if not skip_if_exists:
+                    continue
+                return
+
 
 class Seeder(object):
     def __init__(self, faker):
@@ -142,12 +148,13 @@ class Seeder(object):
         self.quantities[klass] = number
         self.orders.append(klass)
 
-    def execute(self, using=None):
+    def execute(self, using=None, skip_if_exists=False):
         """
         Populate the database using all the Entity classes previously added.
 
         :param using A Django database connection name
         :rtype: A list of the inserted PKs
+        :param skip_if_exists: if True, will not insert if the entity already exists
         """
         if not using:
             using = self.get_connection()
@@ -158,8 +165,9 @@ class Seeder(object):
             if klass not in inserted_entities:
                 inserted_entities[klass] = []
             for i in range(0, number):
-                entity = self.entities[klass].execute(using, inserted_entities)
-                inserted_entities[klass].append(entity)
+                entity = self.entities[klass].execute(using, inserted_entities, skip_if_exists=skip_if_exists)
+                if entity:
+                    inserted_entities[klass].append(entity)
 
         return inserted_entities
 
